/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.geronimo.samples.inventory.web;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.geronimo.samples.inventory.exception.DuplicateItemIdException;
import org.apache.geronimo.samples.inventory.exception.ItemException;
import org.apache.geronimo.samples.inventory.services.InventoryManager;


public class AddItemServlet extends HttpServlet {


    protected void doGet(HttpServletRequest req, HttpServletResponse res) throws ServletException, IOException {
        process(req, res);
    }

    protected void doPost(HttpServletRequest req, HttpServletResponse res) throws ServletException, IOException {
        doGet(req, res);
    }

    private void process(HttpServletRequest req, HttpServletResponse res) throws IOException, ServletException {
        String itemNo = req.getParameter("item_no");
        String itemName = req.getParameter("item_name");
        String description = req.getParameter("item_desc");

        if (!itemNo.equals("") && !itemName.equals("")) {
            InventoryManager itemManager = new InventoryManager();
            try {
                itemManager.addItem(itemNo, itemName, description);
                getServletContext().getRequestDispatcher("/welcome.jsp").forward(req, res);
            } catch (DuplicateItemIdException e) {
                req.setAttribute("error", "Duplicate Item Id");
                getServletContext().getRequestDispatcher("/jsp/error.jsp").forward(req, res);
            } catch (ItemException e) {
                req.setAttribute("Internal error", e.getCause().getMessage());
                getServletContext().getRequestDispatcher("/jsp/error.jsp").forward(req, res);
            }
        } else {
            String error = "";
            if (itemNo.equals("")) {
                error = "Invalid Item Number";
            } else if (itemName.equals("")) {
                error = "Invalid Item Name";
            }
            req.setAttribute("error", error);
            getServletContext().getRequestDispatcher("/jsp/error.jsp").forward(req, res);
        }

    }


}
